@@ -60,32 +60,41 @@ def emotion (ask, url) :
   # Bad
   if inp > bad and inp<5 :
     feel = 'angry'
+    emotion.feelings = 'I am feeling ' + feel + ' about ' + ask
 
   if inp == bad and inp<5 :
     feel = 'sad'
+    emotion.feelings = 'I am feeling ' + feel + ' about ' + ask
 
   if inp < 1 and inp<5 :
     feel = 'scared'
+    emotion.feelings = 'I am feeling ' + feel + ' about ' + ask
 
   # Good
   if inp > good and inp<10 and inp>5 :
     feel = 'excited'
-    
+    emotion.feelings = 'I am feeling ' + feel + ' about ' + ask
 
   if inp < good and inp<10 and inp>5 :
     feel = 'happy'
-
+    emotion.feelings = 'I am feeling ' + feel + ' about ' + ask
 
   if inp == good and inp<10 and inp>5 :
     feel = 'h-cited'
-    
+    emotion.feelings = 'I am feeling ' + feel + ' about ' + ask
 
   if inp == 5 :
     feel = 'nothing'
+    emotion.feelings = 'I am feeling ' + feel + ' about ' + ask
+
+  emotion.mood = 'mood:'+ ovimo
 
   if inp == 100:
 
-    print("Sorry I don't know about " + ask + " ,but I am Curious about it Can you please tell me, How you feel about it? (give the answer in 'angry','sad','scared','excited','happy','h-cited','nothing' : ")
+    print("Sorry I don't know about " + ask + ",")
+    print("But I am Curious about it Can you please tell me,")
+    print( "How you feel about it? (give the answer in 'angry','sad','scared','excited','happy','h-cited','nothing' : ")
+
     l = input()
     if l == 'angry':
       kit = 4
@@ -109,27 +118,21 @@ def emotion (ask, url) :
       kit = 5
       print('Thanks!')
 
-    input = inp
-    feel = kit
+    word = ask
+    feeling = kit
     url = url
 
-    learn(input, feel, url)
+    learn(word, feeling, url)
 
 
+def learn (word, feeling, url):
 
 
-
-  emotion.feelings = 'I am feeling '+ feel+ ' about ' + ask
-  emotion.mood = 'mood:'+ ovimo
-
-def learn (input, feel, url):
-
-
-  l = input
+  l = word
   kit = l
 
   knoutings = kit
-  emI = feel
+  emI = feeling
   from firebase import firebase
   firebase = firebase.FirebaseApplication(url, None)
   firebase.put('/knowlage', knoutings, emI)
